==> elixir-react-stateful-1.2.0.tgz: package/labels/en.js <==
export default {
  login: "Login",
  username: "Username",
  password: "Password",
  usernameWarning: "Please enter username",
  passwordWarning: "Please enter password",
  rememberMe: "Remember Me",
  loginMessage: "Login successfully",
  loginDescription: "Welcome {username}",
  error: "Error",
  newTab: "New Tab",
  error500: "Internal server error",
  error400: "Bad Request",
  home: "Home",
  searchPlaceholder: "Search in main menu",
  tableEmptyText: "No Data",
  networkError: "No connection with the server",
  alerts: "Alerts",
  notifications: "Notifications",
  messages: "Messages",
  favorite: "Favorite",
  more: "More",
  clickToUpload: "Click to upload",
  search: "Search",
  sortBy: "Sort By",
  sortAscending: "Sort Ascending",
  sortDescending: "Sort Descending",
  calculateRows: "Calculate Total Rows Number",
  calculateRowsAlways: "Always Calculate Rows",
  export: "Export",
  savedFilters: "Saved Filters",
  apply: "Apply",
  delete: "Delete",
  restoreDefaultFilter: "Restore Default Filter",
  saveFilter: "Save Current Filter",
  confirmDeleteFilter: "Are you sure you want to delete this filter ?",
  confirmDeleteRelation: "Are you sure you want to delete relation",
  closeCompositionCollapseButtonHint: "Remove ",
  openCompositionCollapseButtonHint: "Add ",
  ok: "Yes",
  no: "No",
  save: "Save",
  cancel: "Cancel",
  filterName: "Filter Name",
  defaultFilter: "Default Filter ?",
  savedSuccessfully: "Saved Successfully",
  deleteSuccessfully: "Deleted Successfully",
  addToFavorite: "Add To Favorite",
  deleteFromFavorite: "Remove From Favorite",
  inFavoriteName: "Name inside the favorite",
  refresh: "Refresh",
  edit: "Edit",
  view: "View",
  add: "Add",
  download: "Download",
  confirm: "Confirm",
  logout: "Logout",
  excel: "Excel",
  pdf: "PDF",
  errorUpload: "Error while uploading file",
  errorNotImage: "You can only upload images",
  actionNotAvailable: "Action not available",
  loading: "Loading ...",
  changeLanguage: "Change Language",
  changePassword:"Change Password",
  loginAsSupervisor:"Login as Admin",
  UserManual:"User Manual",
  SearchCriteria : "Filter for Analysis :",
  numberOfResult : 'number of results',
  '>' : '>',
  '>=' : '>=',
  '<' : '<',
  '<=' : '<='
};

==> elixir-react-stateful-2.0.1.tgz: package/labels/en.js <==
export default {
  login: "Login",
  username: "Username",
  password: "Password",
  usernameWarning: "Please enter username",
  passwordWarning: "Please enter password",
  rememberMe: "Remember Me",
  loginMessage: "Login successfully",
  loginDescription: "Welcome {username}",
  error: "Error",
  newTab: "New Tab",
  error500: "Internal server error",
  error400: "Bad Request",
  home: "Home",
  searchPlaceholder: "Search in main menu",
  tableEmptyText: "No Data",
  networkError: "No connection with the server",
  alerts: "Alerts",
  notifications: "Notifications",
  messages: "Messages",
  favorite: "Favorite",
  more: "More",
  clickToUpload: "Click to upload",
  search: "Search",
  sortBy: "Sort By",
  sortAscending: "Sort Ascending",
  sortDescending: "Sort Descending",
  calculateRows: "Calculate Total Rows Number",
  calculateRowsAlways: "Always Calculate Rows",
  export: "Export",
  savedFilters: "Saved Filters",
  apply: "Apply",
  delete: "Delete",
  restoreDefaultFilter: "Restore Default Filter",
  saveFilter: "Save Current Filter",
  confirmDeleteFilter: "Are you sure you want to delete this filter ?",
  ok: "Yes",
  no: "No",
  save: "Save",
  cancel: "Cancel",
  filterName: "Filter Name",
  defaultFilter: "Default Filter ?",
  savedSuccessfully: "Saved Successfully",
  deleteSuccessfully: "Deleted Successfully",
  addToFavorite: "Add To Favorite",
  deleteFromFavorite: "Remove From Favorite",
  inFavoriteName: "Name inside the favorite",
  refresh: "Refresh",
  edit: "Edit",
  view: "View",
  add: "Add",
  download: "Download",
  confirm: "Confirm",
  logout: "Logout",
  excel: "Excel",
  pdf: "PDF",
  errorUpload: "Error while uploading file",
  loading: "Loading ...",
  changeLanguage: "change language",
dateButton:"Choose Date",
  timeButton:"Choose Time",
  datetimeButton:" Choose Date and Time",
  next:"Next",
  previous:"Previous",
  noOperations: "There are no available operations",
  pageNumber: "Current Page:",
  details:"Details",
  removeCard: "Remove Card",
  generateQR:"Generate QR"
};
